@@ -20,8 +20,8 @@
 *******************************************************************************/
 
 /******************************************************************************
-*   file: cursor.c - funtions related to line editing                         *
 *              (T)he K(I)cki(N) (T)ickin D(I)kumud Clie(N)t                   *
+*                                                                             *
 *                     coded by Igor van den Hoven 2006                        *
 ******************************************************************************/
 
@@ -201,7 +201,20 @@ DO_CURSOR(cursor_convert_meta)
 {
 	SET_BIT(gtd->flags, TINTIN_FLAG_CONVERTMETACHAR);
 }
-	
+
+
+DO_CURSOR(cursor_delete_exit)
+{
+	if (gtd->input_len == 0)
+	{
+		cursor_exit("");
+	}
+	else
+	{
+		cursor_delete("");
+	}
+}
+
 DO_CURSOR(cursor_delete)
 {
 	if (gtd->input_len == 0)
@@ -253,7 +266,7 @@ DO_CURSOR(cursor_delete_word_left)
 
 	sprintf(gtd->paste_buf, "%.*s", index_cur - gtd->input_cur, &gtd->input_buf[gtd->input_cur]);
 
-	memmove(&gtd->input_buf[gtd->input_cur], &gtd->input_buf[index_cur], index_cur + 1);
+	memmove(&gtd->input_buf[gtd->input_cur], &gtd->input_buf[index_cur], gtd->input_len - index_cur + 1);
 
 	input_printf("\033[%dD\033[%dP", index_cur - gtd->input_cur, index_cur - gtd->input_cur);
 
@@ -362,6 +375,8 @@ DO_CURSOR(cursor_enter)
 		{
 			strcpy(gtd->input_buf, gtd->input_his->left);
 		}
+
+		gtd->input_off = 1;
 	}
 	gtd->input_his = NULL;
 
@@ -370,7 +385,14 @@ DO_CURSOR(cursor_enter)
 
 DO_CURSOR(cursor_exit)
 {
-	do_zap(gtd->ses, "");
+	if (gtd->ses == gts)
+	{
+		do_end(NULL, "");
+	}
+	else
+	{
+		cleanup_session(gtd->ses);
+	}
 }
 
 DO_CURSOR(cursor_history_next)
@@ -386,7 +408,7 @@ DO_CURSOR(cursor_history_next)
 
 		for (node = gtd->input_his->next ; node ; node = node->next)
 		{
-			if (*gtd->input_buf && strstr(node->left, gtd->input_buf))
+			if (*gtd->input_buf && find(gtd->ses, node->left, gtd->input_buf))
 			{
 				break;
 			}
@@ -446,7 +468,7 @@ DO_CURSOR(cursor_history_prev)
 
 		for (node = gtd->input_his->prev ; node ; node = node->prev)
 		{
-			if (strstr(node->left, gtd->input_buf))
+			if (find(gtd->ses, node->left, gtd->input_buf))
 			{
 				break;
 			}
@@ -576,7 +598,7 @@ DO_CURSOR(cursor_history_find)
 
 	for (node = root->l_node ; node ; node = node->prev)
 	{
-		if (*gtd->input_buf && strstr(node->left, gtd->input_buf))
+		if (*gtd->input_buf && find(gtd->ses, node->left, gtd->input_buf))
 		{
 			break;
 		}
