@@ -45,9 +45,10 @@ struct help_type help_table[] =
 		"<178>Command<078>: #action <178>{<078>search string<178>}<078> <178>{<078>commands<178>}<078> <178>{<078>priority<178>}<078>\n"
 		"\n"
 		"         Have tintin search for a certain string of text from the mud, if the\n"
-		"         string is found it will execute the commands.  Variables %0 to %9\n"
+		"         string is found it will execute the commands.  Variables %0 to %99\n"
 		"         are substituted from the input string, and can be used in the command.\n"
-		"         Brackets and pipes can be used for selective keywords.\n"
+		"         Brackets and pipes can be used for selective keywords. %{variable} can\n"
+		"         be used to store a variable directly into a tintin variable.\n"
 		"         The third parameter of the command will tell how important tintin\n"
 		"         should reguard this action, 0 most important, 9 least important.  If\n"
 		"         no priority is given, a default value of 5 is assigned.\n"
@@ -56,6 +57,8 @@ struct help_type help_table[] =
 		"         If the search string starts with ^, the start of the line must match.\n"
 		"         If the search string ends with ^, the end of the line must match.\n"
 		"\n"
+		"         Actions can be triggered by the showme command.\n"
+		"\n"
 		"<178>Example<078>: #act {^You are hungry^} {get bread backpack;eat bread}\n"
 		"         Performs 2 commands as you get the hunger message, tintin will not\n"
 		"         be fooled by someone saying 'You are hungry'.\n"
@@ -66,6 +69,8 @@ struct help_type help_table[] =
 		"<178>Example<078>: #act {A puppy barks at you, wagging [his|her|its] tail.} {slap puppy}\n"
 		"         This allows you to deal with annoying puppies regardless of their sex.\n"
 		"\n"
+		"<178>Example<078>: #act {%{reply} tells you '%{lasttell}'} {say $reply said $lasttell}\n"
+		"\n"
 		"<178>Comment<078>: You can remove an action with the #unaction command.\n"
 	},
 	{
@@ -222,6 +227,8 @@ struct help_type help_table[] =
 		"         #CONFIG {COLOR PATCH}  {ON|OFF} Fixes color code usage on some muds.\n"
 		"         #CONFIG {DEBUG TELNET} {ON|OFF} Shows telnet negotiations y/n.\n"
 		"         #CONFIG {LOG LEVEL}  {LOW|HIGH} LOW logs mud output before triggers\n"
+		"         #CONFIG {TIMESTAMP}    {FORMAT} Prepend given strftime format to log\n"
+		"                                         files.\n"
 	},
 	{
 		"CR",
@@ -274,7 +281,10 @@ struct help_type help_table[] =
 		"ECHO",
 		"<178>Command<078>: #echo <178>{<078>format<178>}<078> <178>{<078>argument1 argument2 etc<178>}<078>\n"
 		"\n"
-		"         Echo command displays text on the screen with formatting options.\n"
+		"         Echo command displays text on the screen with formatting options. See\n"
+		"         the help file for the format command for more informations.\n"
+		"\n"
+		"         The echo command does not trigger actions.\n"
 		"\n"
 		"<178>Example<078>: #format {time} {%T}\n"
 		"         #echo {The current time and date is: %d %t} {$time $time}\n"
@@ -636,19 +646,30 @@ struct help_type help_table[] =
 		"         #map flag static: Will make the map static so new rooms are no longer\n"
 		"                  created when walking into an unmapped direction. Useful when\n"
 		"                  you're done mapping and regularly bump into walls accidentally\n"
-		"                  creating a new room.\n"
+		"                  creating a new room. #map dig etc will still work.\n"
+		"\n"
 		"         #map flag vtmap: Will enable the vtmap which is shown in the top split\n"
 		"                  screen if you have one. You can create a 10 rows high top\n"
 		"                  screen by using '#split 10 1'.\n"
 		"\n"
+		"         #map flag asciigraphics: Draws a smaller but more detailed map that\n"
+		"                  displays the ne se sw nw exits and room symbols.\n"
+		"\n"
+		"         #map flag asciivnums: Display room vnums with asciigraphics enabled.\n"
+		"\n"
+		"         #map flag vtgraphics: Enables vt line drawing on some terminals\n"
+		"\n"
 		"         #map goto <room name>: Takes you to the given room name.\n"
 		"\n"
 		"         #map get <option> <variable>: Store a map value into a variable.\n"
 		"\n"
 		"         #map info: Gives information about the map and room you are in.\n"
 		"\n"
-		"         #map insert: Insert a room in the given direction. Useful for\n"
-		"                  inserting void rooms.\n"
+		"         #map insert <direction> [roomflag]: Insert a room in the given\n"
+		"                  direction. Most useful for inserting void rooms.\n"
+		"\n"
+		"         #map jump <x> <y>: Jump to the given coordinate, which is relative\n"
+		"                  to your current room.\n"
 		"\n"
 		"         #map leave: Makes you leave the map. Useful when entering a maze.\n"
 		"\n"
@@ -668,7 +689,9 @@ struct help_type help_table[] =
 		"\n"
 		"         #map list [search string]: Lists all room names and exits.\n"
 		"\n"
-		"         #map map <radius>: shows a map of surrounding rooms.\n"
+		"         #map map {<x>x<y>} {filename}: shows a map of surrounding rooms. The\n"
+		"                  {horizontal x vertical} argument i.e 80x25 is optional, and so\n"
+		"                  is the filename argument to log the map output to file.\n"
 		"\n"
 		"         #map move <direction>: This does the same as an actual movement\n"
 		"                  command, updating your location on the map and creating new\n"
@@ -694,6 +717,8 @@ struct help_type help_table[] =
 		"                  be used to connect otherwise overlapping areas. A void room\n"
 		"                  should only have two exits. When entering a void room you are\n"
 		"                  moved to the connecting room until you enter a non void room.\n"
+		"         #map roomflag static: When set the room will no longer be autolinked\n"
+		"                  when walking around. Useful for mapping mazes.\n"
 		"\n"
 		"         #map set <option> <value>: Set a map value for your current room.\n"
 		"\n"
@@ -729,18 +754,24 @@ struct help_type help_table[] =
 		"         Operators       Priority     Function\n"
 		"         ------------------------------------------------\n"
 		"         !               0            logical not\n"
+		"         ~               0            bitwise not\n"
 		"         *               1            integer multiply\n"
 		"         /               1            integer divide\n"
 		"         %               1            integer modulo\n"
 		"         d               1            integer random dice roll\n"
 		"         +               2            integer addition\n"
 		"         -               2            integer subtraction\n"
+		"         <<              3            bitwise shift\n"
+		"         >>              3            bitwise shift\n"
 		"         >               4            logical greater than\n"
 		"         >=              4            logical greater than or equal\n"
 		"         <               4            logical less than\n"
 		"         <=              4            logical less than or equal\n"
 		"         ==              5            logical equal (can use wildcards)\n"
 		"         !=              5            logical not equal (can use wildcards)\n"
+		"          &              6            bitwise and\n"
+		"          ^              7            bitwise xor\n"
+		"          |              8            bitwise or\n"
 		"         &&              9            logical and\n"
 		"         ^^             10            logical xor\n"
 		"         ||             11            logical or\n"
@@ -826,11 +857,13 @@ struct help_type help_table[] =
 		"         The first argument is a direction, the second argument is the reversed\n"
 		"         direction.  The reverse direction of north is south, etc.\n"
 		"\n"
-		"         The third argument is a spatial coordinate represented as a bitmap.  In\n"
-		"         order to use these check the default values given to n e s w u d by\n"
-		"         typing #pathdir without an argument.  If your mud uses the UE (up east)\n"
-		"         direction you would add the value of U (16) and E (2) and use that as\n"
-		"         the value for the coordinate.\n"
+		"         The third argument is a spatial coordinate. In general, each cardinal\n"
+		"         direction should have a unique value which is a power of two (e.g. 1, 2,\n"
+		"         4, 8, 16, 32, 64, etc). The exception is for compound directions, whose\n"
+		"         value should be the sum of the values for each component direction. For\n"
+		"         example, if the third value for 'n' is 1, and 'e' is 2, then you would\n"
+		"         want 'ne' to have a value of 3 (1 + 2). This value is required for the\n"
+		"         #map functionality to work.\n"
 		"\n"
 		"<178>Example<078>: #pathdir {ue} {dw} {18}\n"
 		"         #pathdir {dw} {ue} {40}\n"
@@ -919,10 +952,10 @@ struct help_type help_table[] =
 	},
 	{
 		"SCRIPT",
-		"<178>Command<078>: #script <178>{<078>shell command<178>}<078>\n"
+		"<178>Command<078>: #script <178>{<078>variable<178>}<178> {<078>shell command<178>}<078>\n"
 		"\n"
 		"         The script command works much like the system command except that it\n"
-		"         treats the generated echos as commands.\n"
+		"         treats the generated echos as commands if no variable is provided.\n"
 		"\n"
 		"         This is useful for running php, perl, ruby, and python scripts. You\n"
 		"         can run these scrips either from file or from within tintin if the\n"
@@ -931,6 +964,7 @@ struct help_type help_table[] =
 		"<178>Example<078>: #script {ruby -e 'print \"#showme hello world\"'}\n"
 		"<178>Example<078>: #script {python -c 'print \"#showme hello world\"'}\n"
 		"<178>Example<078>: #script {php -r 'echo \"#showme hello world\"'}\n"
+		"<178>Example<078>: #script {path} {pwd}\n"
 	},
 
 	{
@@ -968,6 +1002,8 @@ struct help_type help_table[] =
 		"         status, warnings, etc.  The {row} number is optional and works the same\n"
 		"         way as the row number of the #prompt trigger.\n"
 		"\n"
+		"         Actions can be triggered by the showme command.\n"
+		"\n"
 		"<178>Example<078>: #action {%0 ultraslays you.}\n"
 		"           {#showme {###### ARGH! We were ultraslayed by %0 ######};#gagline}\n"
 		"         Emphasis ultraslaying.\n"
