@@ -178,10 +178,17 @@ struct config_type config_table[] =
 	},
 
 	{
-		"ECHO COMMAND",
+		"COMMAND COLOR",
+		"",
+		"The color of echoed commands",
+		config_commandcolor
+	},
+
+	{
+		"COMMAND ECHO",
 		"Your commands are echoed in split mode",
 		"Your commands are not echoed in split mode",
-		config_echocommand
+		config_commandecho
 	},
 
 	{
@@ -247,6 +254,13 @@ struct config_type config_table[] =
 		config_speedwalk
 	},
 
+	{
+		"TIMESTAMP",
+		"Your log files have a timestamp appended to them",
+		"Your log files have no timestamp appended to them",
+		config_timestamp
+	},
+
 	{
 		"TINTIN CHAR",
 		"",
@@ -387,28 +401,31 @@ struct map_type map_table[] =
 	{     "DELETE",                    map_delete,             1,1},
 	{     "DESTROY",                   map_destroy,            1,1},
 	{     "DIG",                       map_dig,                1,1},
-	{     "EXIT",                      map_exit,               0,1},
+	{     "EXITCMD",                   map_exitcmd,            0,1},
+	{     "EXITDIR",                   map_exitdir,            0,1},
 	{     "EXPLORE",                   map_explore,            1,1},
 	{     "FIND",                      map_find,               1,1},
-	{     "FLAG",                      map_flag,               1,1},
+	{     "FLAG",                      map_flag,               0,1},
 	{     "GET",                       map_get,                0,1},
 	{     "GOTO",                      map_goto,               1,1},
 	{     "INFO",                      map_info,               1,1},
-	{     "INSERT",                    map_insert,             1,1},
+	{     "INSERT",                    map_insert,             0,1},
+	{     "JUMP",                      map_jump,               0,0},
 	{     "LEAVE",                     map_leave,              1,1},
-	{     "LEGENDA",                   map_legenda,            1,1},
+	{     "LEGENDA",                   map_legend,             1,1},
 	{     "LINK",                      map_link,               0,1},
 	{     "LIST",                      map_list,               1,1},
-	{     "MAP",                       map_map,                1,1},
+	{     "MAP",                       map_map,                0,0},
 	{     "MOVE",                      map_move,               1,1},
 	{     "NAME",                      map_name,               1,1},
 	{     "READ",                      map_read,               1,1},
-	{     "ROOMFLAG",                  map_roomflag,           1,1},
+	{     "RETURN",                    map_return,             0,0},
+	{     "ROOMFLAG",                  map_roomflag,           0,1},
+	{     "RUN",                       map_run,                0,1},
 	{     "SET",                       map_set,                0,1},
-	{     "TRAVEL",                    map_travel,             1,1},
+	{     "TRAVEL",                    map_travel,             0,1},
 	{     "UNDO",                      map_undo,               1,1},
 	{     "UNLINK",                    map_unlink,             0,1},
-	{     "WALK",                      map_walk,               1,1},
 	{     "WRITE",                     map_write,              1,1},
 	{     "",                          NULL,                   1,1}
 };
@@ -428,7 +445,6 @@ struct cursor_type cursor_table[] =
 		"[6~",
 		buffer_d
 	},
-
 	{
 		"",
 		"",
@@ -453,7 +469,6 @@ struct cursor_type cursor_table[] =
 		"",
 		cursor_home
 	},
-
 	{
 		"",
 		"",
@@ -486,23 +501,18 @@ struct cursor_type cursor_table[] =
 		cursor_left
 	},
 	{
-		"EXIT",
-		"Exit current session",
+		"CLEAR LINE",
+		"Delete the input line",
 		"",
-		cursor_exit
+		cursor_clear_line
 	},
 	{
-		"DELETE",
-		"Delete character at cursor",
+		"CTRL DELETE",
+		"Delete character at cursor, or exit on empty line",
 		"",
-		cursor_delete
-	},
-	{
-		"",
-		"",
-		"[3~",
-		cursor_delete
+		cursor_delete_exit
 	},
+
 	{
 		"END",
 		"Move cursor to end of input",
@@ -539,7 +549,6 @@ struct cursor_type cursor_table[] =
 		"OC",
 		cursor_right
 	},
-
 	{
 		"BACKSPACE",
 		"Delete backward character",
@@ -648,6 +657,18 @@ struct cursor_type cursor_table[] =
 		"",
 		cursor_suspend
 	},
+	{
+		"DELETE",
+		"Delete character at cursor",
+		"[3~",
+		cursor_delete
+	},
+	{
+		"EXIT",
+		"Exit current session",
+		"",
+		cursor_exit
+	},
 	{
 		"ECHO",
 		"Turn local echoing on or off",
