@@ -118,7 +118,7 @@ typedef void            LINE    (struct session *ses, char *arg);
 #define BUFFER_SIZE                  15000
 #define NUMBER_SIZE                    100
 
-#define VERSION_NUM               "1.98.3"
+#define VERSION_NUM               "1.98.7"
 
 #define ESCAPE                          27
 
@@ -315,11 +315,13 @@ typedef void            LINE    (struct session *ses, char *arg);
 #define ROOM_FLAG_HIDE                (1 <<  1)
 #define ROOM_FLAG_LEAVE               (1 <<  2)
 #define ROOM_FLAG_VOID                (1 <<  3)
+#define ROOM_FLAG_STATIC              (1 <<  4)
 
 #define MAP_FLAG_STATIC               (1 <<  0)
 #define MAP_FLAG_VTMAP                (1 <<  1)
 #define MAP_FLAG_VTGRAPHICS           (1 <<  2)
 #define MAP_FLAG_ASCIIGRAPHICS        (1 <<  3)
+#define MAP_FLAG_ASCIIVNUMS           (1 <<  4)
 
 #define MAP_EXIT_N                    (1 <<  0)
 #define MAP_EXIT_E                    (1 <<  1)
@@ -470,6 +472,8 @@ typedef void            LINE    (struct session *ses, char *arg);
 #define SET_BIT(bitvector, bit)   ((bitvector) |= (bit))
 #define DEL_BIT(bitvector, bit)   ((bitvector) &= (~(bit)))
 #define TOG_BIT(bitvector, bit)   ((bitvector) ^= (bit))
+#define FFS_BIT(bitvector)        ((ffs(bitvector) - 1)) 
+
 
 /*
 	Compatibility
@@ -534,10 +538,12 @@ struct session
 	int                     flags;
 	char                  * host;
 	char                  * port;
+	char                  * timestamp;
 	long long               connect_retry;
 	int                     connect_error;
 	char                    more_output[STRING_SIZE];
 	char                    color[100];
+	char                    command_color[100];
 	long long               check_output;
 };
 
@@ -722,9 +728,11 @@ struct str_hash_index_data
 struct map_data
 {
 	struct room_data      * room_list[MAX_ROOM];
+	FILE                  * logfile;
 	int                     flags;
 	int                     in_room;
-	char                    legenda[17][100];
+	int                     last_room;
+	char                    legend[17][100];
 };
 
 struct room_data
@@ -744,6 +752,7 @@ struct exit_data
 	struct exit_data        * next;
 	struct exit_data        * prev;
 	short                     vnum;
+	short                     dir;
 	char                    * name;
 	char                    * cmd;
 };
@@ -774,6 +783,7 @@ extern DO_CURSOR(cursor_clear_line);
 extern DO_CURSOR(cursor_clear_right);
 extern DO_CURSOR(cursor_convert_meta);
 extern DO_CURSOR(cursor_delete);
+extern DO_CURSOR(cursor_delete_exit);
 extern DO_CURSOR(cursor_delete_word_left);
 extern DO_CURSOR(cursor_delete_word_right);
 extern DO_CURSOR(cursor_echo);
@@ -805,7 +815,7 @@ extern DO_CURSOR(cursor_tab);
 #define __INPUT_H__
 
 extern void process_input(void);
-extern void read_line(void);
+extern void read_line();
 extern void read_key(void);
 extern void convert_meta(char *input, char *output);
 extern void unconvert_meta(char *input, char *output);
@@ -944,7 +954,8 @@ extern DO_MAP(map_create);
 extern DO_MAP(map_delete);
 extern DO_MAP(map_destroy);
 extern DO_MAP(map_dig);
-extern DO_MAP(map_exit);
+extern DO_MAP(map_exitcmd);
+extern DO_MAP(map_exitdir);
 extern DO_MAP(map_explore);
 extern DO_MAP(map_find);
 extern DO_MAP(map_flag);
@@ -952,20 +963,22 @@ extern DO_MAP(map_get);
 extern DO_MAP(map_goto);
 extern DO_MAP(map_info);
 extern DO_MAP(map_insert);
+extern DO_MAP(map_jump);
 extern DO_MAP(map_leave);
-extern DO_MAP(map_legenda);
+extern DO_MAP(map_legend);
 extern DO_MAP(map_link);
 extern DO_MAP(map_list);
 extern DO_MAP(map_map);
 extern DO_MAP(map_move);
 extern DO_MAP(map_name);
 extern DO_MAP(map_read);
+extern DO_MAP(map_return);
 extern DO_MAP(map_roomflag);
+extern DO_MAP(map_run);
 extern DO_MAP(map_set);
 extern DO_MAP(map_travel);
 extern DO_MAP(map_undo);
 extern DO_MAP(map_unlink);
-extern DO_MAP(map_walk);
 extern DO_MAP(map_write);
 
 extern void create_map(struct session *ses);
@@ -974,7 +987,7 @@ extern int  create_room(struct session *ses, char *arg);
 extern void delete_room(struct session *ses, int room, int exits);
 extern void create_exit(struct session *ses, int room, char *arg);
 extern void delete_exit(struct session *ses, int room, struct exit_data *exit);
-extern void create_legenda(struct session *ses, char *arg);
+extern void create_legend(struct session *ses, char *arg);
 extern int  find_room(struct session *ses, char *arg);
 extern void goto_room(struct session *ses, int room);
 extern struct exit_data *find_exit(struct session *ses, int room, char *arg);
@@ -985,11 +998,12 @@ extern void build_map_grid(short room, short x, short y, short z);
 extern void follow_map(struct session *ses, char *argument);
 extern void insert_undo(struct session *ses, char *format, ...);
 extern char *draw_room(struct session *ses, struct room_data *room, int line);
-extern void search_path(short room, short size);
-extern void shortest_path(struct session *ses, int walk, char *left, char *right);
-extern void explore_path(struct session *ses, int walk, char *left, char *right);
+extern void search_path(short room, short size, short dir);
+extern void fill_map(struct session *ses);
+extern void shortest_path(struct session *ses, int run, char *left, char *right);
+extern void explore_path(struct session *ses, int run, char *left, char *right);
 extern int find_coord(struct session *ses, char *arg);
-extern void search_coord(int vnum, short x, short y, short z);
+extern void search_coord_bf(int vnum);
 extern void show_vtmap(struct session *ses);
 
 #endif
@@ -1032,6 +1046,7 @@ extern void do_one_prompt(struct session *ses, char *prompt, int row);
 #define __TINEXP_H__
 
 extern int match(struct session *ses, char *str, char *exp);
+extern int find(struct session *ses, char *str, char *exp);
 extern int glob(char *str, char *exp);
 DO_COMMAND(do_regexp);
 extern int regexp_cmds(char *str, char *exp);
@@ -1040,7 +1055,7 @@ extern int action_regexp(char *str, char *exp);
 
 extern void substitute(struct session *ses, char *string, char *result, int flags);
 extern int check_one_action(char *line, char *original, char *action, struct session *ses);
-extern int action_glob(char *str, char *exp, unsigned char arg);
+extern int action_glob(struct session *ses, char *str, char *exp, unsigned char arg);
 
 #endif
 
@@ -1053,7 +1068,8 @@ extern DO_COMMAND(do_configure);
 extern DO_CONFIG(config_speedwalk);
 extern DO_CONFIG(config_verbatim);
 extern DO_CONFIG(config_repeatenter);
-extern DO_CONFIG(config_echocommand);
+extern DO_CONFIG(config_commandecho);
+extern DO_CONFIG(config_commandcolor);
 extern DO_CONFIG(config_verbose);
 extern DO_CONFIG(config_wordwrap);
 extern DO_CONFIG(config_log);
@@ -1070,6 +1086,7 @@ extern DO_CONFIG(config_convertmeta);
 extern DO_CONFIG(config_loglevel);
 extern DO_CONFIG(config_colorpatch);
 extern DO_CONFIG(config_regexp);
+extern DO_CONFIG(config_timestamp);
 
 #endif
 
@@ -1206,6 +1223,7 @@ extern int get_highlight_codes(struct session *ses, char *htype, char *result);
 
 extern DO_COMMAND(do_history);
 extern void add_line_history(struct session *ses, char *line);
+extern void insert_line_history(struct session *ses, char *line);
 extern void search_line_history(struct session *ses, char *line);
 extern int write_history(struct session *ses, char *filename);
 extern int read_history(struct session *ses, char *filename);
@@ -1252,7 +1270,7 @@ extern DO_COMMAND(do_debug);
 #ifndef __LOG_H__
 #define __LOG_H__
 
-extern void logit(struct session *ses, char *txt, FILE *file);
+extern void logit(struct session *ses, char *txt, FILE *file, int newline);
 extern DO_COMMAND(do_log);
 extern DO_COMMAND(do_logline);
 extern DO_COMMAND(do_writebuffer);
@@ -1511,9 +1529,11 @@ extern void memory_update(void);
 
 extern int is_abbrev(char *s1, char *s2);
 extern int is_suffix(char *s1, char *s2);
+extern int is_color_code(char *str);
 extern int is_number(char *str);
 extern int hex_number(char *str);
 extern long long utime(void);
+extern char *timestamp(char *str);
 extern char *capitalize(char *str);
 extern void cat_sprintf(char *dest, char *fmt, ...);
 extern void ins_sprintf(char *dest, char *fmt, ...);
@@ -1576,6 +1596,7 @@ extern void strip_vt102_codes_non_graph(char *str, char *buf);
 extern void strip_non_vt102_codes(char *str, char *buf);
 extern void get_color_codes(char *old, char *str, char *buf);
 extern int strip_vt102_strlen(char *str);
+extern int strip_color_strlen(char *str);
 extern int interpret_vt102_codes(struct session *ses, char *str, int real);
 
 #endif
